@@ -221,7 +221,7 @@ class Logger(metaclass=_Singleton):
         self.__logs = {}
 
     @contextmanager
-    def disabled(self, log_tag: LogTagBase = None, why: str = ''):
+    def disabled(self, log_tag: Union[LogTagBase, str] = None, why: str = ''):
         """
         WARNING! This disables all logging in a context. This trumps all rules and modes as no logs
         will be processed or printed to the console. Use carefully. Upon exit of the context the logger
@@ -239,10 +239,13 @@ class Logger(metaclass=_Singleton):
             logger.info('I am logged!')
 
         Args:
-            log_tag: The log tag that logs why. Defaults to the default tag.
+            log_tag: The LogTagBase object or one of 'debug', 'info', 'warning', 'error', or 'critical'.
             why: A description of why logging is being disabled.
         """
-        log_tag = log_tag or self.default_log_tag
+        if isinstance(log_tag, str):
+            log_tag = self.default_log_tags[log_tag]
+        else:
+            log_tag = log_tag or self.default_log_tag
         num_prev_callers = 2
         orig_state = self._disabled
         try:
@@ -397,21 +400,25 @@ class Logger(metaclass=_Singleton):
         """
         self.log(msg=msg, log_tag=self.default_log_tags.critical, num_prev_callers=num_prev_callers + 1)
 
-    def log(self, msg: Any, log_tag: LogTagBase = None, num_prev_callers: int = 0):
+    def log(self, msg: Any, log_tag: Union[LogTagBase, str] = None, num_prev_callers: int = 0):
         """
         Logs a message with the ``log_tag`` log tag if given, else the ``default_log_tag``, which, if
         not explicitly set, defaults to the INFO log tag.
 
         Args:
             msg: Log message.
-            log_tag: A LogTagType to tag to the log message.
+            log_tag: The LogTagBase object or one of 'debug', 'info', 'warning', 'error', or 'critical'.
             num_prev_callers: Number of previous calls in the call stack that identifies the
                 originator of the log message. This should rarely, if ever, be set, but is
                 configurable should a a previous caller be tied to the log message.
         """
         if self._disabled:
             return
-        log_tag = log_tag or self.default_log_tag
+
+        if isinstance(log_tag, str):
+            log_tag = self.default_log_tags[log_tag]
+        else:
+            log_tag = log_tag or self.default_exception_tag
         thread = threading.current_thread()
         if lt := self._threads.get(thread.ident):
             no_console, no_persistence = lt.blacklisted(log_tag)
@@ -423,17 +430,21 @@ class Logger(metaclass=_Singleton):
         self._commit_log(msg=msg, log_tag=log_tag, file_path=file_path, line_num=line_num, func=func,
                          no_console=no_console, no_persistence=no_persistence)
 
-    def log_exception(self, log_tag: LogTagBase = None):
+    def log_exception(self, log_tag: Union[LogTagBase, str] = None):
         """
         Logs an exception using `traceback.format_exc()` with the ``log_tag`` log tag if given, else
         the ``default_exception_tag``, which, if not explicitly set, defaults to the CRITICAL log tag.
 
         Args:
-           log_tag: A LogTagType object that suits an exception. If not given
+           log_tag: The LogTagBase object or one of 'debug', 'info', 'warning', 'error', or 'critical'.
+                    The ``default_exception_tag`` is used by default.
         """
         if self._disabled:
             return
-        log_tag = log_tag or self.default_exception_tag
+        if isinstance(log_tag, str):
+            log_tag = self.default_log_tags[log_tag]
+        else:
+            log_tag = log_tag or self.default_exception_tag
         with self.OP_LOCK:
             tb = sys.exc_info()[2]
 
@@ -454,7 +465,7 @@ class Logger(metaclass=_Singleton):
         self._commit_log(msg=msg, log_tag=log_tag, file_path=outer_frames[1], line_num=outer_frames[2],
                          func=func)
 
-    def log_method(self, func: callable, msg: Any, log_tag: LogTagBase = None, returning: bool = False):
+    def log_method(self, func: callable, msg: Any, log_tag: Union[LogTagBase, str] = None, returning: bool = False):
         """
         Logs a call or exit of a method or function with the name of the callable and the given ``msg``
         with the ``log_tag`` log tag if given, else the ``default_log_tag``, which, if not explicitly set,
@@ -463,12 +474,15 @@ class Logger(metaclass=_Singleton):
         Args:
             func: A callable object.
             msg: The log message.
-            log_tag: The LogTagType object.
+            log_tag: The LogTagBase object or one of 'debug', 'info', 'warning', 'error', or 'critical'.
             returning: If ``True`` gets the last line number of the function instead of the first for the log.
         """
         if self._disabled:
             return
-        log_tag = log_tag or self.default_log_tag
+        if isinstance(log_tag, str):
+            log_tag = self.default_log_tags[log_tag]
+        else:
+            log_tag = log_tag or self.default_log_tag
         thread = threading.current_thread()
         if lt := self._threads.get(thread.ident):
             no_console, no_persistence = lt.blacklisted(log_tag)
@@ -488,7 +502,7 @@ class Logger(metaclass=_Singleton):
         )
 
     @contextmanager
-    def rule(self, log_tag: LogTagBase = None, min_level: str = None,
+    def rule(self, log_tag: Union[LogTagBase, str] = None, min_level: str = None,
              blacklist_function: Callable[[LogTagBase], Tuple[bool, bool]] = None, why: str = ''):
         """
         The context manager equivalent of ``set_rule()``. When the context exits the ``default_log_rule``
@@ -496,7 +510,7 @@ class Logger(metaclass=_Singleton):
         restrictions enforced by the rules.
 
         Args:
-            log_tag: The LogTagType object.
+            log_tag: The LogTagBase object or one of 'debug', 'info', 'warning', 'error', or 'critical'.
             min_level: If a string, must be one of 'debug', 'info', 'warning', 'error', or 'critical', from
                        which the value of the respective default log tag type is used as a minimum threshold
                        for a log event to occur. Otherwise it must be an integer.
@@ -511,7 +525,7 @@ class Logger(metaclass=_Singleton):
         yield
         self._set_rule(log_tag=log_tag, reset=True, num_prev_callers=2)
 
-    def set_mode(self, mode: str, log_tag: LogTagBase = None, why: str = ''):
+    def set_mode(self, mode: str, log_tag: Union[LogTagBase, str] = None, why: str = ''):
         """
         The log mode can be used to change where the logs are recorded. This is useful for simply
         reducing noise in the log output.
@@ -525,14 +539,17 @@ class Logger(metaclass=_Singleton):
 
         Args:
             mode: One of 'current', 'console', 'persistence', or 'all'. Default is 'current'. Case sensitive.
-            log_tag: The log tag that logs why. Defaults to the default INFO log tag.
+            log_tag: The LogTagBase object or one of 'debug', 'info', 'warning', 'error', or 'critical'.
             why: A description of why the mode is being set.
         """
         if self._disabled:
             return
 
         thread = threading.current_thread()
-        log_tag = log_tag or self.default_log_tag
+        if isinstance(log_tag, str):
+            log_tag = self.default_log_tags[log_tag]
+        else:
+            log_tag = log_tag or self.default_log_tag
         msg = f'Setting log mode to "{mode}". '
         if why:
             msg += f" => {why}"
@@ -552,7 +569,7 @@ class Logger(metaclass=_Singleton):
         self._commit_log(msg=msg, log_tag=log_tag, file_path=file_path, line_num=line_num, func=func,
                          force=True)
 
-    def set_rule(self, log_tag: LogTagBase = None, min_level: str = None,
+    def set_rule(self, log_tag: Union[LogTagBase, str] = None, min_level: str = None,
                  blacklist_function: Callable[[LogTagBase], Tuple[bool, bool]] = None,
                  reset: bool = False, why: str = ''):
         """
@@ -560,7 +577,7 @@ class Logger(metaclass=_Singleton):
         log output. Only one of ``min_level``, ``blacklist_function``, or ``reset`` can be specified.
 
         Args:
-            log_tag: The LogTagType object.
+            log_tag: The LogTagBase object or one of 'debug', 'info', 'warning', 'error', or 'critical'.
             min_level: If a string, must be one of 'debug', 'info', 'warning', 'error', or 'critical', from
                        which the value of the respective default log tag type is used as a minimum threshold
                        for a log event to occur. Otherwise it must be an integer.
@@ -597,7 +614,7 @@ class Logger(metaclass=_Singleton):
             )
         }
 
-    def wrap_class(self, log_tag: LogTagBase = None, func_regex_exclude: str = '', mask_input_regexes: List = None,
+    def wrap_class(self, log_tag: Union[LogTagBase, str] = None, func_regex_exclude: str = '', mask_input_regexes: List = None,
                    mask_output: bool = False, mask_output_regexes: List = None):
         """
         Applies ``wrap_func()`` to each callable member of a class that does not start with "__" and does not
@@ -606,13 +623,16 @@ class Logger(metaclass=_Singleton):
         parameters are passed to the ``wrap_func()`` method.
 
         Args:
-            log_tag: The log tag to apply to each method wrapped.
+            log_tag: The LogTagBase object or one of 'debug', 'info', 'warning', 'error', or 'critical'.
             func_regex_exclude: A regular expression matching method names that should not be wrapped.
             mask_input_regexes: Passed to ``wrap_func()``.
             mask_output: Passed to ``wrap_func()``.
             mask_output_regexes: Passed to ``wrap_func()``..
         """
-        log_tag = log_tag or self.default_log_tag
+        if isinstance(log_tag, str):
+            log_tag = self.default_log_tags[log_tag]
+        else:
+            log_tag = log_tag or self.default_log_tag
         if isinstance(mask_output_regexes, list):
             with _LoggerPickler.LOCK:
                 _LoggerPickler.MASKED_REGEXES = list(set(_LoggerPickler.MASKED_REGEXES + mask_output_regexes))
@@ -647,7 +667,7 @@ class Logger(metaclass=_Singleton):
             return cls
         return _wrap
 
-    def wrap_func(self, log_tag: LogTagBase = None, mask_input_regexes: List = None, mask_output: bool = False,
+    def wrap_func(self, log_tag: Union[LogTagBase, str] = None, mask_input_regexes: List = None, mask_output: bool = False,
                   mask_output_regexes: List = None, is_staticmethod: bool = False, is_classmethod: bool = False):
         """
         Wrapper for a function or method. This wrapper performs a few important steps:
@@ -692,7 +712,7 @@ class Logger(metaclass=_Singleton):
               }
 
         Args:
-            log_tag: The log tag to apply to the input and output log messages.
+            log_tag: The LogTagBase object or one of 'debug', 'info', 'warning', 'error', or 'critical'.
             mask_input_regexes: A list of regular expressions matching input variable names.
             mask_output: When ``True`` the entire  output is masked like this: "********".
             mask_output_regexes: A list of regular expressions of keys whose values ought to be masked in the
@@ -701,7 +721,10 @@ class Logger(metaclass=_Singleton):
             is_classmethod: If ``True`` then the method is intended to be a classmethod.
             is_staticmethod: If ``True`` the the method is intended to be a staticmethod.
         """
-        log_tag = log_tag or self.default_log_tag
+        if isinstance(log_tag, str):
+            log_tag = self.default_log_tags[log_tag]
+        else:
+            log_tag = log_tag or self.default_log_tag
         if isinstance(mask_output_regexes, list):
             with _LoggerPickler.LOCK:
                 _LoggerPickler.MASKED_REGEXES = list(set(_LoggerPickler.MASKED_REGEXES + mask_output_regexes))
@@ -781,7 +804,7 @@ class Logger(metaclass=_Singleton):
 
         Args:
             msg: Log message.
-            log_tag: The log tag that logs the message. Defaults to the default tag.
+            log_tag: The LogTagBase object.
             file_path: Absolute path to the file in relation to the log message.
             line_num: Line number in the ``file_path``.
             func: Optional. The qualified name of the function in relation to the ``line_num``.
@@ -838,13 +861,16 @@ class Logger(metaclass=_Singleton):
                 func = outer_frames.function
         return func, outer_frames[1], outer_frames[2]
 
-    def _set_rule(self, log_tag: LogTagBase = None, min_level: str = None,
+    def _set_rule(self, log_tag: Union[LogTagBase, str] = None, min_level: Union[LogTagBase, str] = None,
                   blacklist_function: Callable[[LogTagBase], Tuple[bool, bool]] = None,
                   reset: bool = False, why: Union[str, bool] = '', num_prev_callers: int = 0):
         if self._disabled:
             return
 
-        log_tag = log_tag or self.default_log_tag
+        if isinstance(log_tag, str):
+            log_tag = self.default_log_tags[log_tag]
+        else:
+            log_tag = log_tag or self.default_log_tag
         thread = threading.current_thread()
         if lt := self._threads.get(thread.ident):
             if lt.blacklist_log_tag and log_tag.value < lt.blacklist_log_tag.value:
@@ -855,19 +881,9 @@ class Logger(metaclass=_Singleton):
             if isinstance(min_level, int):
                 level = min_level
             elif isinstance(min_level, str):
-                if min_level == 'debug':
-                    level = self.default_log_tags.debug.value
-                elif min_level == 'info':
-                    level = self.default_log_tags.info.value
-                elif min_level == 'warning':
-                    level = self.default_log_tags.warning.value
-                elif min_level == 'error':
-                    level = self.default_log_tags.error.value
-                elif min_level == 'critical':
-                    level = self.default_log_tags.critical.value
-                else:
-                    raise ValueError('min_level must be one of "debug", "info", "warning", "error" or '
-                                     '"critical", or an integer.')
+                level = self.default_log_tags[min_level].value
+            elif isinstance(min_level, LogTagBase):
+                level = min_level.value
             else:
                 raise ValueError('min_level must be one of "debug", "info", "warning", "error" or '
                                  '"critical", or an integer.')
